@@ -140,6 +140,15 @@ class TestSample(unittest.TestCase):
     def test_normalize_samples_030_cisco_asa_msg(self):
         self.normalize_samples('cisco-asa_msg.xml', 'cisco-asa_msg', 0.99)
 
+    def test_normalize_samples_031_openLDAP(self):
+        self.normalize_samples('openLDAP.xml', 'openLDAP', 0.99)
+
+    def test_normalize_samples_031_openLDAP_extras(self):
+        self.normalize_samples('openLDAP-extras.xml', 'openLDAP-extras', 0.99)
+        
+    def test_normalize_samples_032_squidguard(self):
+        self.normalize_samples('squidguard.xml', 'squidguard', 0.99)
+
 class TestCSVPattern(unittest.TestCase):
     """Test CSVPattern behaviour"""
     normalizer_path = os.environ['NORMALIZERS_PATH']
