@@ -31,11 +31,13 @@ import test_normalizer
 import test_lognormalizer
 import test_log_samples
 import test_commonElements
+import test_extras
 
 tests = (test_commonElements,
          test_normalizer,
          test_lognormalizer,
          test_log_samples,
+         test_extras,
          )
 
 load = unittest.defaultTestLoader.loadTestsFromModule
